MethodChannelFlutterRefreshRateControl class

An implementation of FlutterRefreshRateControlPlatform that uses method channels.

Inheritance

Properties

exceptionOnUnsupportedPlatform → bool
Indicates whether an exception should be thrown on unsupported platforms. If set to true, an exception will be thrown when trying to use refresh rate control on a platform that does not support it (e.g., web, desktop).
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel?
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
getRefreshRateInfo() → Future<Map<String, dynamic>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestHighRefreshRate() → Future<bool>
override
setExceptionOnUnsupportedPlatform(bool value) → void
Sets whether an exception should be thrown on unsupported platforms.
override
stopHighRefreshRate() → Future<bool>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited